import commonjs from '@rollup/plugin-commonjs';
// import builtins from 'rollup-plugin-node-builtins';
import json from '@rollup/plugin-json';
import babel from '@rollup/plugin-babel';
import resolve from '@rollup/plugin-node-resolve';
import replace from '@rollup/plugin-replace';
import { basicWebpackBabelConfig } from '@knapsack/babel-config-starter';
import { join } from 'path';
import { DEFAULT_EXTENSIONS } from '@babel/core';

const isProd = process.env.NODE_ENV === 'production';
const extensions = ['.ts', '.tsx', ...DEFAULT_EXTENSIONS];
const distDir = join(__dirname, './dist');

/** @type {import('rollup').RollupOptions} */
const baseConfig = {
  input: {
    'renderer-client': join(__dirname, './src/index.ts'),
  },
  preserveEntrySignatures: false,
  plugins: [
    resolve({
      extensions,
    }),
    replace({
      'process.env.NODE_ENV': JSON.stringify(
        isProd ? 'production' : 'development',
      ),
      preventAssignment: true,
    }),
    commonjs({
      include: [/node_modules/],
    }),
    json(),
  ],
  // onwarn(warn, defaultHandler) {},
};

/** @type {import('rollup').RollupOptions} */
const modernConfig = {
  ...baseConfig,
  output: {
    format: 'esm',
    dir: distDir,
    entryFileNames: '[name].mjs',
    chunkFileNames: '[name]-[hash].mjs',
    assetFileNames: 'assets/[name]-[hash][extname]',
  },
  plugins: [
    ...baseConfig.plugins,
    babel({
      babelrc: false,
      ...basicWebpackBabelConfig,
      extensions,
      exclude: /node_modules/,
      babelHelpers: 'inline',
    }),
  ],
};

export default modernConfig;
